pub(crate) struct CargoTargetSpec {
pub(crate) workspace_root: AbsPathBuf,
pub(crate) cargo_toml: ManifestPath,
pub(crate) package: String,
pub(crate) package_id: Arc<PackageId>,
pub(crate) target: String,
pub(crate) target_kind: TargetKind,
pub(crate) crate_id: Crate,
pub(crate) required_features: Vec<String>,
pub(crate) features: FxHashSet<String>,
pub(crate) sysroot_root: Option<AbsPathBuf>,
}Expand description
Abstract representation of Cargo target.
We use it to cook up the set of cli args we need to pass to Cargo to build/test/run the target.
Fields
workspace_root: AbsPathBufcargo_toml: ManifestPathpackage: Stringpackage_id: Arc<PackageId>target: Stringtarget_kind: TargetKindcrate_id: Craterequired_features: Vec<String>features: FxHashSet<String>sysroot_root: Option<AbsPathBuf>Implementations
Sourceimpl CargoTargetSpec
impl CargoTargetSpec
pub(crate) fn runnable_args( snap: &GlobalStateSnapshot, spec: Option<CargoTargetSpec>, kind: &RunnableKind, cfg: &Option<CfgExpr>, ) -> (Vec<String>, Vec<String>)
pub(crate) fn override_command( snap: &GlobalStateSnapshot, spec: Option<CargoTargetSpec>, kind: &RunnableKind, ) -> Option<Vec<String>>
fn executable_args_for( kind: &RunnableKind, extra_test_binary_args: impl IntoIterator<Item = String>, ) -> Vec<String>
pub(crate) fn push_to(self, buf: &mut Vec<String>, kind: &RunnableKind)